==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/calendar/language/nb.php <==
<?php


$l['name'] = 'Kalender';
$l['description'] = 'Kalendemodul: Alle brukere kan legge til, redigere og slette avtaler. Man kan også se andre brukeres avtaler, og de kan endres om nødvendig.';
$l['groupView'] = 'Gruppevisning';
$l['event']='Hendelse';
$l['startsAt']='Begynner';
$l['endsAt']='Slutter';
$l['exceptionNoCalendarID'] = 'FATAL: Ingen kalender-ID!';
$l['appointment'] = 'Avtale: ';
$l['allTogether'] = 'Alle sammen';
$l['location']='Lokasjon';
$l['invited']='Du er invitert til følgende hendelse';
$l['acccept_question']='Aksepterer du denne hendelsen?';
$l['accept']='Aksepter';
$l['decline']='Avvis';
$l['bad_event']='Denne hendelsen eksisterer ikke lenger';
$l['subject']='Emne';
$l['status']='Status';
$l['statuses']['NEEDS-ACTION'] = 'Trenger handling';
$l['statuses']['ACCEPTED'] = 'Akseptert';
$l['statuses']['DECLINED'] = 'Avvist';
$l['statuses']['TENTATIVE'] = 'Tentativ';
$l['statuses']['DELEGATED'] = 'Delegert';
$l['statuses']['COMPLETED'] = 'Fullført';
$l['statuses']['IN-PROCESS'] = 'Under behandling';
$l['accept_mail_subject'] = 'Invitasjon til \'%s\' er akseptert';
$l['accept_mail_body'] = '%s har akseptert din invitasjon til:';
$l['decline_mail_subject'] = 'Invitasjon til \'%s\' er avvist';
$l['decline_mail_body'] = '%s har avvist din invitasjon til:';
$l['location']='Lokasjon';
$l['and']='og';
$l['repeats'] = 'Gjentas hver %s';
$l['repeats_at'] = 'Gjentas hver %s på %s';//eg. Repeats every month at the first monday;
$l['repeats_at_not_every'] = 'Gjentas hver %s %s på %s';//eg. Repeats every 2 weeks at monday;
$l['until']='til og med'; ;
$l['not_invited']='Du er ikke blitt invitert til denne hendelsen. Det kan være at du må logge inn som en annen bruker.';
$l['accept_title']='Akseptert';
$l['accept_confirm']='Avsender vil få beskjed om at du har akseptert hendelsen';
$l['decline_title']='Avvist';
$l['decline_confirm']='Avsender vil få beskjed om at du har avvist hendelsen';
$l['cumulative']='Ugyldig gjentagelsesregel. Neste forskomst kan ikke starte før den forrige er ferdig.';
$l['already_accepted']='Du har allerede akseptert denne hendelsen.';
$l['private']='Privat';
$l['import_success']='%s hendelser er importert';
$l['printTimeFormat']='Fra %s til %s';
$l['printLocationFormat']=' på lokasjonen "%s"';
$l['printPage']='Side %s av %s';
$l['printList']='Avtaleoversikt';
$l['printAllDaySingle']='Hele dagen';
$l['printAllDayMultiple']='Hele dagen fra %s til %s';
$l['calendars']='Kalendere';
$l['resource_mail_subject']='Ressursen \'%s\' er reservert'; //%s is resource name;
$l['resource_mail_body']='%s ønsker å reservere ressursen \'%s\'. Du er ansvarlig for denne ressursen. Du må åpne bestillingen for å bekrefte eller avvise reservasjonen.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['open_resource']='Åpne bestilling';
$l['resource_modified_mail_subject']='Endring i bestilling av ressursen \'%s\' ';//%s is resource name;
$l['resource_modified_mail_body']='%s har endret en bestilling av ressursen \'%s\'. Du er ansvarlig for denne ressursen. Du må åpne bestillingen for å bekrefte eller avvise endringen.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_modified_mail_subject']='Din bestilling av \'%s\' med status %s er endret';
$l['your_resource_modified_mail_body']='%s her endret sin bestilling av ressursen \'%s\'.';
$l['your_resource_accepted_mail_subject']= 'Bestilling av \'%s\' er akseptert';//%s is resource name, status;
$l['your_resource_accepted_mail_body']= '%s har akseptert din bestilling av ressursen \'%s\'.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_declined_mail_subject']= 'Bestilling av \'%s\' er avvist';//%s is resource name;
$l['your_resource_declined_mail_body']= '%s har avvist din bestilling av ressursen \'%s\'.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['birthday_name']='Fødselsdag: {NAME}';
$l['birthday_desc']='{NAME} fyller {AGE} i dag';
$l['unauthorized_participants_write']='Du har ikke tilstrekkelige rettigheter til å registrere avtaler for disse brukerne:<br /><br />{NAMES}<br /><br />I stedet kan du sende dem en invitasjon, slik at de selv kan akseptere og registrere avtalen.';
$l['noCalSelected']= 'Det er ikke valgt noen kalendere for denne oversikten. Velg minst en kalender i Administrasjon.';
$l['month_times'][1]='den første';
$l['month_times'][2]='den andre';
$l['month_times'][3]='den tredje';
$l['month_times'][4]='den fjerde';
$l['month_times'][5]='den femte';
$l['repeats_not_every']= 'Gjentas hver %s %s';
$l['rightClickToCopy']='Høyreklikk for å kopiere lenkelokasjon';
$l['invitation']='Invitasjon';
$l['invitation_update']='Oppdatert invitasjon';
$l['cancellation']='Kansellering';
$l['non_selected']= 'i ikke-valgt kalender';
$l['statuses']['CONFIRMED']= 'Bekreftet';
$l['linkIfCalendarNotSupported']='Bruk bare lenkene nedenfor hvis e-postprogrammet ditt ikke støtter kalenderfunksjoner.';
$l["addressbook"]='Adressebok';
$l["appointment"]= 'Avtale';
$l["appointments"]= 'Avtaler';
$l["recurrence"]= 'Gjentagelse';
$l["options"]= 'Innstillinger';
$l["repeatForever"]= 'Gjenta for alltid';
$l["repeatEvery"]= 'Gjenta hver';
$l["repeatUntil"]= 'Gjenta til og med';
$l["busy"]= 'Vis som opptatt';
$l["allDay"]= 'Klokkeslett ikke aktuelt';
$l["navigation"]= 'Navigasjon';
$l["oneDay"]= '1 dag';
$l["fiveDays"]= '5 dager';
$l["sevenDays"]= '7 dager';
$l["month"]= 'Måned';
$l["recurringEvent"]= 'Gjentagende hendelse';
$l["deleteRecurringEvent"]= 'Vil du slette en enkel hendelse eller alle gjentagelser av denne hendelsen?';
$l["singleOccurence"]= 'Enkel hendelse';
$l["entireSeries"]= 'Hele serien';
$l["calendar"]= 'Kalender';
$l["calendars"]= 'Kalendere';
$l["views"]= 'Visninger';
$l["administration"]= 'Administrasjon';
$l["needsAction"]= 'Trenger oppfølging';
$l["accepted"]= 'Akseptert';
$l["declined"]= 'Avvist';
$l["tentative"]= 'Tentativ';
$l["delegated"]= 'Delegert';
$l["noRecurrence"]= 'Ingen gjentagelse';
$l["notRespondedYet"]= 'Avventer svar';
$l["days"]= 'dag';
$l["weeks"]= 'uke';
$l["monthsByDate"]= 'måned på dato';
$l["monthsByDay"]= 'måned på dag';
$l["years"]= 'år';
$l["atDays"]= 'På dag';
$l["noReminder"]= 'Ingen påminnelse';
$l["reminder"]='Påminnelse';
$l["participants"]= 'Deltagere';
$l["checkAvailability"]= 'Sjekk tilgjengelighet';
$l["sendInvitation"]= 'Send invitasjon';
$l["emailSendingNotConfigured"]= 'Sending av e-post er ikke konfigurert!';
$l["privateEvent"]= 'Privat';
$l["noInformationAvailable"]= 'Ingen tilgjengelig informasjon';
$l["noParticipantsToDisplay"]= 'Ingen deltagere å vise';
$l["previousDay"]= 'Forrige dag';
$l["nextDay"]= 'Neste dag';
$l["noAppointmentsToDisplay"]= 'Ingen avtaler å vise';
$l["selectCalendar"]= 'Velg kalender';
$l["selectCalendarForAppointment"]= 'Velg kalender hvor denne avtalen skal registreres:';
$l["closeWindow"]= 'Avtalen er akseptert og registrert i kalenderen. Du kan lukke vinduet nå.';
$l["list"]='Liste';
$l["editRecurringEvent"]='Vil du endre denne hendelsen eller hele serien?';
$l["selectIcalendarFile"]='Velg en icalendar (*.ics) fil';
$l["location"]='Lokasjon';
$l["startsAt"]='Starter';
$l["endsAt"]='Slutter';
$l["eventDefaults"]='Standardinstillinger for avtaler';
$l["importToCalendar"]='Legg avtalen direkte i kalenderne';
$l["default_calendar"]='Standardkalender';
$l["status"]='Status';
$l["resource_groups"]='Ressursgrupper';
$l["resource_group"]='Ressursgruppe';
$l["resources"]='Ressurser';
$l["resource"]='Ressurs';
$l["calendar_group"]='Kalendergruppe';
$l["admins"]='Administratorer';
$l["no_group_selected"]='Det er feil ved utfyllingen. Du må velge en gruppe for denne ressursen.';
$l["visibleCalendars"]='Synlige kalendere';
$l["visible"]='Synlig';
$l["group"]='Gruppe';
$l["no_status"]='Ny';
$l["no_custom_fields"]='Det er ingen flere ekstrainstillinger tilgjengelig.';
$l["show_bdays"]='Vis fødselsdager fra adressebøker';
$l["show_tasks"]='Vis oppgaver fra oppgavelister';
$l["myCalendar"]='Min kalender';
$l["merge"]='Slå sammen';
$l["ownColor"]= 'Hver kalender i sin egen farge';
$l["ignoreConflictsTitle"]= 'Ignorere konflikter?';
$l["ignoreConflictsMsg"]= 'Denne hendelsen er i konflikt med en annen hendelse i kalenderen din. Lagre hendelsen likevel?';
$l["resourceConflictTitle"]= 'Ressurskonflikt';
$l["resourceConflictMsg"]= 'En eller flere ressurser i denne hendelsen er allerede i bruk på samme tidspunkt:</br>';
$l["view"]= 'Vis';
$l["calendarsPermissions"]='Kalendertillatelser';
$l["resourcesPermissions"]='Ressurstillatelser';
$l["categories"]='Kategorier';
$l["category"]='Kategori';
$l["globalCategory"]='Global kategori';
$l["selectCategory"]='Velg kategori';
$l["duration"]='Tidsrom';
$l["move"]='Flytt';
$l["showInfo"]='Detaljer';
$l["copyEvent"]='Kopier hendelse';
$l["moveEvent"]='Flytt hendelse';
$l["eventInfo"]='Hendelsesdetaljer';
$l["isOrganizer"]='Organisator';
$l["sendInvitationInitial"]='Vil du sende møteinvitasjoner til deltagerne?';
$l["sendInvitationUpdate"]='Vil du sende oppdatert møteinformasjon til deltagerne?';
$l["sendCancellation"]='Vil du sende melding om avlysning til alle deltagere?';
$l["forthcomingAppointments"]='Kommende avtaler';
$l["quarterShort"]= 'KV';
$l["globalsettings_templatelabel"]= 'Mal';
$l["globalsettings_allchangelabel"]= 'Gi nytt navn til alle eksisterende';
$l["globalsettings_renameall"]= 'Er du sikker på at du vil gi nytt navn til alle brukernes standarkalendere?';
$l["publishICS"]='Publiser en iCalendarfil med forrige måned og alle framridige hendelser. ADVARSEL! Kalenderen vil være lesbar for alle.';
$l["addTimeRegistration"]='Importer til timeregistrering';
$l["showNotBusy"]='Ikke sett nye reservasjoner som opptatt';
$l["sendEmailParticipants"]= 'Lag e-post til deltagerne';
$l["confirmed"]= 'Bekreftet';
$l["globalCategories"]='Globale kategorier';
$l['eventAccepted']='Du har akseptert hendelsen.';
$l['eventScheduledIn']='Denne hendelsen er nå lagt inn i din kalender: %s med status %s.';
$l['eventDeclined']="Du har avvist hendelsen.";
$l['eventUpdatedIn']='Hendelsen i kalenderen %s er oppdatert med status %s';
$l['updateReponses'][1]='%s har akseptert hendelsen %s';
$l['updateReponses'][2]='%s har avvist hendelsen %s';
$l['updateReponses'][3]='%s har merket hendelsen %s som tentativ';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/calendar/language/nb.php <==
<?php


$l['name'] = 'Kalender';
$l['description'] = 'Kalendemodul: Alle brukere kan legge til, redigere og slette avtaler. Man kan også se andre brukeres avtaler, og de kan endres om nødvendig.';
$l['groupView'] = 'Gruppevisning';
$l['event']='Hendelse';
$l['startsAt']='Begynner';
$l['endsAt']='Slutter';
$l['exceptionNoCalendarID'] = 'FATAL: Ingen kalender-ID!';
$l['appointment'] = 'Avtale: ';
$l['allTogether'] = 'Alle sammen';
$l['location']='Lokasjon';
$l['invited']='Du er invitert til følgende hendelse';
$l['acccept_question']='Aksepterer du denne hendelsen?';
$l['accept']='Aksepter';
$l['decline']='Avvis';
$l['bad_event']='Denne hendelsen eksisterer ikke lenger';
$l['subject']='Emne';
$l['status']='Status';
$l['statuses']['NEEDS-ACTION'] = 'Trenger handling';
$l['statuses']['ACCEPTED'] = 'Akseptert';
$l['statuses']['DECLINED'] = 'Avvist';
$l['statuses']['TENTATIVE'] = 'Tentativ';
$l['statuses']['DELEGATED'] = 'Delegert';
$l['statuses']['COMPLETED'] = 'Fullført';
$l['statuses']['IN-PROCESS'] = 'Under behandling';
$l['accept_mail_subject'] = 'Invitasjon til \'%s\' er akseptert';
$l['accept_mail_body'] = '%s har akseptert din invitasjon til:';
$l['decline_mail_subject'] = 'Invitasjon til \'%s\' er avvist';
$l['decline_mail_body'] = '%s har avvist din invitasjon til:';
$l['location']='Lokasjon';
$l['and']='og';
$l['repeats'] = 'Gjentas hver %s';
$l['repeats_at'] = 'Gjentas hver %s på %s';//eg. Repeats every month at the first monday;
$l['repeats_at_not_every'] = 'Gjentas hver %s %s på %s';//eg. Repeats every 2 weeks at monday;
$l['until']='til og med'; ;
$l['not_invited']='Du er ikke blitt invitert til denne hendelsen. Det kan være at du må logge inn som en annen bruker.';
$l['accept_title']='Akseptert';
$l['accept_confirm']='Avsender vil få beskjed om at du har akseptert hendelsen';
$l['decline_title']='Avvist';
$l['decline_confirm']='Avsender vil få beskjed om at du har avvist hendelsen';
$l['cumulative']='Ugyldig gjentagelsesregel. Neste forskomst kan ikke starte før den forrige er ferdig.';
$l['already_accepted']='Du har allerede akseptert denne hendelsen.';
$l['private']='Privat';
$l['import_success']='%s hendelser er importert';
$l['printTimeFormat']='Fra %s til %s';
$l['printLocationFormat']=' på lokasjonen "%s"';
$l['printPage']='Side %s av %s';
$l['printList']='Avtaleoversikt';
$l['printAllDaySingle']='Hele dagen';
$l['printAllDayMultiple']='Hele dagen fra %s til %s';
$l['calendars']='Kalendere';
$l['resource_mail_subject']='Ressursen \'%s\' er reservert'; //%s is resource name;
$l['resource_mail_body']='%s ønsker å reservere ressursen \'%s\'. Du er ansvarlig for denne ressursen. Du må åpne bestillingen for å bekrefte eller avvise reservasjonen.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['open_resource']='Åpne bestilling';
$l['resource_modified_mail_subject']='Endring i bestilling av ressursen \'%s\' ';//%s is resource name;
$l['resource_modified_mail_body']='%s har endret en bestilling av ressursen \'%s\'. Du er ansvarlig for denne ressursen. Du må åpne bestillingen for å bekrefte eller avvise endringen.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_modified_mail_subject']='Din bestilling av \'%s\' med status %s er endret';
$l['your_resource_modified_mail_body']='%s her endret sin bestilling av ressursen \'%s\'.';
$l['your_resource_accepted_mail_subject']= 'Bestilling av \'%s\' er akseptert';//%s is resource name, status;
$l['your_resource_accepted_mail_body']= '%s har akseptert din bestilling av ressursen \'%s\'.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_declined_mail_subject']= 'Bestilling av \'%s\' er avvist';//%s is resource name;
$l['your_resource_declined_mail_body']= '%s har avvist din bestilling av ressursen \'%s\'.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['birthday_name']='Fødselsdag: {NAME}';
$l['birthday_desc']='{NAME} fyller {AGE} i dag';
$l['unauthorized_participants_write']='Du har ikke tilstrekkelige rettigheter til å registrere avtaler for disse brukerne:<br /><br />{NAMES}<br /><br />I stedet kan du sende dem en invitasjon, slik at de selv kan akseptere og registrere avtalen.';
$l['noCalSelected']= 'Det er ikke valgt noen kalendere for denne oversikten. Velg minst en kalender i Administrasjon.';
$l['month_times'][1]='den første';
$l['month_times'][2]='den andre';
$l['month_times'][3]='den tredje';
$l['month_times'][4]='den fjerde';
$l['month_times'][5]='den femte';
$l['repeats_not_every']= 'Gjentas hver %s %s';
$l['rightClickToCopy']='Høyreklikk for å kopiere lenkelokasjon';
$l['invitation']='Invitasjon';
$l['invitation_update']='Oppdatert invitasjon';
$l['cancellation']='Kansellering';
$l['non_selected']= 'i ikke-valgt kalender';
$l['statuses']['CONFIRMED']= 'Bekreftet';
$l['linkIfCalendarNotSupported']='Bruk bare lenkene nedenfor hvis e-postprogrammet ditt ikke støtter kalenderfunksjoner.';
$l["addressbook"]='Adressebok';
$l["appointment"]= 'Avtale';
$l["appointments"]= 'Avtaler';
$l["recurrence"]= 'Gjentagelse';
$l["options"]= 'Innstillinger';
$l["repeatForever"]= 'Gjenta for alltid';
$l["repeatEvery"]= 'Gjenta hver';
$l["repeatUntil"]= 'Gjenta til og med';
$l["busy"]= 'Vis som opptatt';
$l["allDay"]= 'Klokkeslett ikke aktuelt';
$l["navigation"]= 'Navigasjon';
$l["oneDay"]= '1 dag';
$l["fiveDays"]= '5 dager';
$l["sevenDays"]= '7 dager';
$l["month"]= 'Måned';
$l["recurringEvent"]= 'Gjentagende hendelse';
$l["deleteRecurringEvent"]= 'Vil du slette en enkel hendelse eller alle gjentagelser av denne hendelsen?';
$l["singleOccurence"]= 'Enkel hendelse';
$l["entireSeries"]= 'Hele serien';
$l["calendar"]= 'Kalender';
$l["calendars"]= 'Kalendere';
$l["views"]= 'Visninger';
$l["administration"]= 'Administrasjon';
$l["needsAction"]= 'Trenger oppfølging';
$l["accepted"]= 'Akseptert';
$l["declined"]= 'Avvist';
$l["tentative"]= 'Tentativ';
$l["delegated"]= 'Delegert';
$l["noRecurrence"]= 'Ingen gjentagelse';
$l["notRespondedYet"]= 'Avventer svar';
$l["days"]= 'dag';
$l["weeks"]= 'uke';
$l["monthsByDate"]= 'måned på dato';
$l["monthsByDay"]= 'måned på dag';
$l["years"]= 'år';
$l["atDays"]= 'På dag';
$l["noReminder"]= 'Ingen påminnelse';
$l["reminder"]='Påminnelse';
$l["participants"]= 'Deltagere';
$l["checkAvailability"]= 'Sjekk tilgjengelighet';
$l["sendInvitation"]= 'Send invitasjon';
$l["emailSendingNotConfigured"]= 'Sending av e-post er ikke konfigurert!';
$l["privateEvent"]= 'Privat';
$l["noInformationAvailable"]= 'Ingen tilgjengelig informasjon';
$l["noParticipantsToDisplay"]= 'Ingen deltagere å vise';
$l["previousDay"]= 'Forrige dag';
$l["nextDay"]= 'Neste dag';
$l["noAppointmentsToDisplay"]= 'Ingen avtaler å vise';
$l["selectCalendar"]= 'Velg kalender';
$l["selectCalendarForAppointment"]= 'Velg kalender hvor denne avtalen skal registreres:';
$l["closeWindow"]= 'Avtalen er akseptert og registrert i kalenderen. Du kan lukke vinduet nå.';
$l["list"]='Liste';
$l["editRecurringEvent"]='Vil du endre denne hendelsen eller hele serien?';
$l["selectIcalendarFile"]='Velg en icalendar (*.ics) fil';
$l["location"]='Lokasjon';
$l["startsAt"]='Starter';
$l["endsAt"]='Slutter';
$l["eventDefaults"]='Standardinstillinger for avtaler';
$l["importToCalendar"]='Legg avtalen direkte i kalenderne';
$l["default_calendar"]='Standardkalender';
$l["status"]='Status';
$l["resource_groups"]='Ressursgrupper';
$l["resource_group"]='Ressursgruppe';
$l["resources"]='Ressurser';
$l["resource"]='Ressurs';
$l["calendar_group"]='Kalendergruppe';
$l["admins"]='Administratorer';
$l["no_group_selected"]='Det er feil ved utfyllingen. Du må velge en gruppe for denne ressursen.';
$l["visibleCalendars"]='Synlige kalendere';
$l["visible"]='Synlig';
$l["group"]='Gruppe';
$l["no_status"]='Ny';
$l["no_custom_fields"]='Det er ingen flere ekstrainstillinger tilgjengelig.';
$l["show_bdays"]='Vis fødselsdager fra adressebøkene';
$l["show_tasks"]='Vis oppgaver fra oppgavelister';
$l["myCalendar"]='Min kalender';
$l["merge"]='Slå sammen';
$l["ownColor"]= 'Hver kalender i sin egen farge';
$l["ignoreConflictsTitle"]= 'Ignorere konflikter?';
$l["ignoreConflictsMsg"]= 'Denne hendelsen er i konflikt med en annen hendelse i kalenderen din. Lagre hendelsen likevel?';
$l["resourceConflictTitle"]= 'Ressurskonflikt';
$l["resourceConflictMsg"]= 'En eller flere ressurser i denne hendelsen er allerede i bruk på samme tidspunkt:</br>';
$l["view"]= 'Vis';
$l["calendarsPermissions"]='Kalendertillatelser';
$l["resourcesPermissions"]='Ressurstillatelser';
$l["categories"]='Kategorier';
$l["category"]='Kategori';
$l["globalCategory"]='Global kategori';
$l["selectCategory"]='Velg kategori';
$l["duration"]='Tidsrom';
$l["move"]='Flytt';
$l["showInfo"]='Detaljer';
$l["copyEvent"]='Kopier hendelse';
$l["moveEvent"]='Flytt hendelse';
$l["eventInfo"]='Hendelsesdetaljer';
$l["isOrganizer"]='Organisator';
$l["sendInvitationInitial"]='Vil du sende møteinvitasjoner til deltagerne?';
$l["sendInvitationUpdate"]='Vil du sende oppdatert møteinformasjon til deltagerne?';
$l["sendCancellation"]='Vil du sende melding om avlysning til alle deltagere?';
$l["forthcomingAppointments"]='Kommende avtaler';
$l["quarterShort"]= 'KV';
$l["globalsettings_templatelabel"]= 'Mal';
$l["globalsettings_allchangelabel"]= 'Gi nytt navn til alle eksisterende';
$l["globalsettings_renameall"]= 'Er du sikker på at du vil gi nytt navn til alle brukernes standarkalendere?';
$l["publishICS"]='Publiser en iCalendarfil med forrige måned og alle framridige hendelser. ADVARSEL! Kalenderen vil være lesbar for alle.';
$l["addTimeRegistration"]='Importer til timeregistrering';
$l["showNotBusy"]='Ikke sett nye reservasjoner som opptatt';
$l["sendEmailParticipants"]= 'Lag e-post til deltagerne';
$l["confirmed"]= 'Bekreftet';
$l["globalCategories"]='Globale kategorier';
$l['eventAccepted']='Du har akseptert hendelsen.';
$l['eventScheduledIn']='Denne hendelsen er nå lagt inn i din kalender: %s med status %s.';
$l['eventDeclined']="Du har avvist hendelsen.";
$l['eventUpdatedIn']='Hendelsen i kalenderen %s er oppdatert med status %s';
$l['updateReponses'][1]='%s har akseptert hendelsen %s';
$l['updateReponses'][2]='%s har avvist hendelsen %s';
$l['updateReponses'][3]='%s har merket hendelsen %s som tentativ';
$l['cancelMessage']='Følgende hendelse som du er invitert til er blitt kansellert.';
